% Michael Vodhanel

% Purpose: Draws a vector format image as a subfigure

% Input:
%	Fig: The function or image in vector format
%	Height: The y coordinate of the function when drawn
%	Width: The x coordinate of the function when drawn
%	FigTitle: The title string for the subfigure
%	FigType: 'f' for function, 'i' for image

% Output:
%	The image to the screen

function Draw_Sub_Fig(Fig, Height, Width, FigTitle, FigType)

% draw function type
if strcmp(lower(FigType), 'f')
   if Width * Height == length(Fig)
		x = [1:1:Width];
		y = [1:1:Height];

	surf(x, y, reshape(Fig, Height, Width));
	   title(FigTitle);
	else
	   fprintf('\nError in Draw_Fig: Width*Height must equal the length of the function vector\n\n')
   end
   
% draw image type
elseif strcmp(lower(FigType), 'i')
   % set image into [0, 1]
	Fig = max(0, min(1, Fig));

	image(reshape(Fig, Height, Width, 3));
	title(FigTitle);
	view(2);
	set(gca,'xtick', [],'ytick', []);
	axis equal;axis tight;drawnow;
   
else
   fprintf('\nError in Draw_Fig: Must have valid figure type\n\n')
end