% Michael Vodhanel

% Purpose: Used POD to find the most dominant modes of a collection of snapshots

% Input:
%	Snapshots:	The collection of data samples.  Each column is one snapshot. 
%	NumOfModes:	The number of dominant modes to find
%	Center:		boolean value, 1 to center the data before the POD algorithm
%					and add the center back afterwords.  0 to just use POD

% Output:
%	Phi: The characteristic images (modes) of the snapshots


%Change history
%Nasser Abbasi 060607
% fix the sign of the dominant eigenvector of the covariance matrix
% as we do in PCA analysis in the code used for the paper

function Phi = POD_Modes(Snapshots, NumOfModes, Center)

Ns = size(Snapshots, 2)
Theta = zeros(Ns);
Phi = zeros(size(Snapshots,1), NumOfModes);

% Remove X_bar, the mean of the snapshots, if centering
Center=0;  %nasser
if Center == 1
   X_bar = sum(Snapshots')' / Ns;
   Snapshots = Snapshots - repmat(X_bar, 1, Ns);
end

 for i=1:Ns
       av=sum(Snapshots(i,:))/Ns;
       Snapshots(i,:)=Snapshots(i,:)-av;
 end

% Create covariance matrix
% for i = 1:Ns
%     for j = i:Ns
%         Theta(i, j) = sum(Snapshots(:, i).* Snapshots(:, j) );
%     end
% end

for i = 1:Ns
     for j = i:Ns         
         Theta(i, j) = dot(Snapshots(:, i),Snapshots(:, j) ); %nma032807
     end
end

for i = 2:Ns
    for j = 1:i-1
        Theta(i, j) = Theta(j, i);
    end
end

% Find the first NumOfModes dominant phi's
[V,D]=eig(Theta);
for i = 1:NumOfModes
    w = V(:,Ns - i + 1);  %notice, eigenvalues are allready returned
                          %sorted such that last eigenvalue is largest
                          %and last eigvector is corresponding.
    w = w / sum(abs(w)); 
    w = w / sum(w);
    
    for k = 1:Ns
        Phi(:,i) = Phi(:,i) + w(k) * Snapshots(:, k);  %eq (6) in paper
    end
end
 
% added code to fix the sign
for j=1:NumOfModes   %nabbasi 
    sumP1(j)=0.;

    for i=1:Ns
        sumP1(j)=sumP1(j)+sum(Snapshots(:, i)'*Phi(:,j));        
    end
    sumP1(j);
    if sumP1(j) < 0
        Phi(:,j)=-Phi(:,j);
    end

    % Projections...
    for k=1:Ns
       Phi(:,j) = Phi(:,j) + w(k) * Snapshots(:, k);  %eq (6) in paper
    end
end



% Replace X_bar, the mean of the snapshots, if centering was performed
if Center == 1
	Snapshots = Snapshots + repmat(X_bar, 1, Ns);   
end
